# setup.py

import os
import setuptools

setuptools.setup(
    name="rwsdigital_utils",
    version="2022.6.7.0",
    description="Odoo Development Utils by RWS Digital",
    long_description="Utils for Odoo development including dates and datetimes manipulation and more",
    long_description_content_type="text/x-rst",
    readme="README.md",
    author="Salvatore Castaldo",
    author_email = "salvatore@rwsdigital.com",
    license="MIT License",
    url = "https://github.com/sCast17/rwsdigital_utils",
    classifiers = [
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    )
